@@ -13,6 +13,7 @@ from bot.helptexts import (
     ruless,
     warnhelpp,
     antifloodhelpp,
+    blacklisthelpp,
 )
 from telethon import events, functions, Button
 import bot.utilsbot
@@ -21,6 +22,10 @@ import bot.utilsbot
 async def _(event):
     await event.edit(f"{warnhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
 
+@callback("blacklisthelp")
+async def _(event):
+    await event.edit(f"{blacklisthelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+
 @callback("antifloodhelp")
 async def _(event):
     await event.edit(f"{antifloodhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
